@@ -194,8 +194,8 @@ impl Backend for Git {
         Ok(())
     }
 
-    fn log(&self, skip: usize, len: usize) -> BackendResult<Vec<LogEntry>> {
-        let skip = skip.to_string();
+    fn log(&self, skip: usize, len: usize) -> BackendResult<(usize, Vec<LogEntry>)> {
+        let skip_text = skip.to_string();
         let len = len.to_string();
         let template = "--format=format:%x00%h%x00%as%x00%aN%x00%D%x00%s";
         let output = Process::spawn(
@@ -207,7 +207,7 @@ impl Backend for Git {
                 "--oneline",
                 "--graph",
                 "--skip",
-                &skip,
+                &skip_text,
                 "--max-count",
                 &len,
                 template,
@@ -236,7 +236,7 @@ impl Backend for Git {
             });
         }
 
-        Ok(entries)
+        Ok((skip, entries))
     }
 
     fn checkout(&self, revision: &str) -> BackendResult<()> {
@@ -286,8 +286,8 @@ impl Backend for Git {
         let mut entries = Vec::new();
         loop {
             let status = match splits.next() {
-                Some(status) => parse_file_status(status),
-                None => break,
+                Some(status) if !status.is_empty() => parse_file_status(status),
+                _ => break,
             };
             let name = match splits.next() {
                 Some(name) => name.into(),
